searchData={"content_type":"text/markdown","items":[{"doc":"Briefly cache LiveView assigns to prevent recalculating them during connected mounts.\n\nFor example:\n\n- Cache a database query to avoid duplicate identical queries, resulting in a faster connected mount\n- Cache a random value to determine which content to display in an A/B test\n\nBy using `assign_cached/4`, an assign evaluated during the disconnected mount\nof a LiveView is temporarily cached in ETS, for retrieval during the connected mount that\nimmediately follows.\n\n    def mount(_params, _session, socket) do\n      socket = assign_cached(socket, :users, fn ->\n        Accounts.list_users()\n      end)\n\n      {:ok, socket}\n    end\n\nCached values are not stored for very long. The cache is invalidated as soon as the connected\nmount occurs, or after 5 seconds (configurable), whichever comes first. In the event of a\ncache miss, the function is evaluated again.\n\nLive navigation to the LiveView will always result in a cache miss.\n\nThe caching of LiveComponent assigns is not currently supported.","ref":"LiveCache.html","title":"LiveCache","type":"module"},{"doc":"For assigns that depend on external parameters, the `:scope` option can be used to guarantee\nuniqueness of the stored value.\n\n    def mount(%{\"id\" => id}, _session, socket) do\n      socket = assign_cached(socket, :post, fn -> Blog.get_post(id) end, scope: id)\n      {:ok, socket}\n    end","ref":"LiveCache.html#module-scoping-cached-values","title":"Scoping Cached Values - LiveCache","type":"module"},{"doc":"The cache is rehydrated by storing a one-time key in a ` ` tag in the DOM, which is\nthen passed as a connection param when the `LiveSocket` client connects. For enhanced security,\nthe cached values can also be scoped to the current session with the `LiveCache.PerSession` plug.\n\nThe cache is stored locally in ETS, and is not distributed. If your production application has\nmultiple nodes running behind a load balancer, the load balancer must be configured with \"sticky\nsessions\" so that subsequent requests from the same user are handled by the same node.","ref":"LiveCache.html#module-implementation-details","title":"Implementation Details - LiveCache","type":"module"},{"doc":"Add `live_cache` to your list of dependencies in `mix.exs`:\n\n    def deps do\n      [\n        {:live_cache, \"~> 0.2.0\"}\n      ]\n    end\n\nIn `my_app_web.ex`, update the `live_view` definition.\n\n    defmodule MyAppWeb do\n      def live_view do\n        quote do\n          # [...]\n          import LiveCache\n          on_mount LiveCache.LiveView\n        end\n      end\n    end\n\nIn the root template `root.html.heex`, add a meta tag to the ` `:\n\n```html\n \n \n```\n\nIn `app.js`, modify the `LiveSocket` client constructor to include the value from the meta tag:\n\n```js\nlet csrfToken = document.querySelector(\"meta[name='csrf-token']\").getAttribute(\"content\");\nlet liveCacheKey = document.querySelector(\"meta[name='live-cache-key']\").getAttribute(\"content\");\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  params: { _csrf_token: csrfToken, live_cache_key: liveCacheKey },\n});\n```\n\nFinally, add the `LiveCache.PerSession` plug to the router. This step is optional but highly recommended, as it\nensures that cached values can only be retrieved from the session in which they were stored.\n\n    defmodule MyAppWeb.Router do\n      use MyAppWeb, :router\n\n      pipeline :browser do\n        # [...]\n        plug LiveCache.PerSession\n      end\n    end","ref":"LiveCache.html#module-installation","title":"Installation - LiveCache","type":"module"},{"doc":"The default config is below.\n\n    config :live_cache,\n      ttl: :timer.seconds(5),          # Cache expiration time, in milliseconds; set to 0 to disable caching\n      sweep_every: :timer.seconds(1)   # How frequently the cache is purged","ref":"LiveCache.html#module-configuration","title":"Configuration - LiveCache","type":"module"},{"doc":"Put an assign value, populating it from the cache if available.\n\nOn a cache hit during a connected mount, the cached value is used.\n\nOn a cache miss during a connected or disconnected mount, the result of `fun` is used. During the disconnected\nmount, this value is stored in the cache with an expiration.","ref":"LiveCache.html#assign_cached/4","title":"LiveCache.assign_cached/4","type":"function"},{"doc":"- `:scope` - unique conditions to associate with this assign","ref":"LiveCache.html#assign_cached/4-options","title":"Options - LiveCache.assign_cached/4","type":"function"},{"doc":"def mount(_params, _session, socket) do\n      socket = assign_cached(socket, :address, fn ->\n        Accounts.get_address(socket.assigns.current_user)\n      end)\n\n      {:ok, socket}\n    end\n\n    def handle_params(%{\"order_by\" => _order_by} = params, _uri, socket) do\n      # Only cache the orders list for a specific set of query params\n      socket = assign_cached(socket, :orders, fn -> Orders.list_orders(params) end, scope: params)\n      {:noreply, socket}\n    end","ref":"LiveCache.html#assign_cached/4-examples","title":"Examples - LiveCache.assign_cached/4","type":"function"},{"doc":"Put a new assign value, populating it from the cache if available.\n\nThis function is identical to `assign_cached/4`, except it falls back to\n`Phoenix.Component.assign_new/3` on a cache miss.\n\nIn other words, the order of priority for evaluating the assign is:\n\n1. Try to fetch from the cache.\n2. Try to fetch from existing assigns.\n3. Evaluate the anonymous function.","ref":"LiveCache.html#assign_cached_new/4","title":"LiveCache.assign_cached_new/4","type":"function"},{"doc":"Integration hook for LiveViews.","ref":"LiveCache.LiveView.html","title":"LiveCache.LiveView","type":"module"},{"doc":"LiveView `on_mount` callback to integrate with LiveCache.\n\nThis function should not called directly. It is a callback invoked via `Phoenix.LiveView.on_mount/1`","ref":"LiveCache.LiveView.html#on_mount/4","title":"LiveCache.LiveView.on_mount/4","type":"function"},{"doc":"Plug to scope cache operations to the current session.\n\nInstalling the plug into a pipeline ensures that cached values are only accessible within this session, as an extra\nlayer of security.\n\n    defmodule MyAppWeb.Router do\n      use MyAppWeb, :router\n\n      pipeline :browser do\n        # [...]\n        plug LiveCache.PerSession\n      end","ref":"LiveCache.PerSession.html","title":"LiveCache.PerSession","type":"module"}]}